#include <iostream>
#include <ctime>
#include <omp.h>
#include <cstdlib>

using namespace std;

// define f so that integral of f from 0 to 1 is Pi
inline double f(const double x) {
  return (4.0/(1.0+x*x));
}

int main(int argc, char *argv[]) {
 
  // number of integration steps
  int n = 1000000;
  if (argc == 2)  n = atoi(argv[1]);

  // start clock
  clock_t t1=clock();
  #ifdef _OPENMP
  double wt1=omp_get_wtime();
  #endif

/* calculate pi = integral [0..1] 4/(1+x**2) dx */
  double w   = 1.0/n;   
  double sum = 0.0;

  for (int i=0;i<n;i++) {
      double x=w*(double(i)+0.5);
      sum += 4.0/(1.0+x*x);
  }
  double pi=w*sum;

  clock_t t2=clock();
 
  cout << "number of slices      = " << n << endl;
  cout << "computed pi           = " << pi << endl;
  cout << "CPU time (clock in s) = " << double(t2-t1)/CLOCKS_PER_SEC << endl;
}
